<?php
/*
Plugin Name: jsearch - Multiple category, tag, and term search
Plugin URI: http://www.thegeekprofessor.com/jsearch-plugin
Description: Feed the loop with results that match the combination of tags, keywords, and categories you specify. Each of the different searchable data has it's own wordpress widget which can be controlled via your admin interface
Author: Jeremy Duffy
Version: 2
Author URI: http://www.thegeekprofessor.com/
*/

require_once("jsearch_functions.php");

function widget_jsearch_init()
{
	global $wpdb;

	if (!function_exists('register_sidebar_widget'))
		return;

	// Add our custom menu to the controls
	add_action('admin_menu', 'jsearch_admin_panel');

	// Gets the set options and sets defaults for any that aren't already set
	function jsearch_get_options()
	{
		global $jsearch_options_defaults;
		
		$options = get_option('widget_jsearch_options');
		if (!is_array($options))	// It's never been set or was cleared for some reason.
		{
			update_option('widget_jsearch_options',$jsearch_options_defaults);
			return $jsearch_options_defaults;
		}
		else
			foreach($jsearch_options_defaults as $key => $a_default)
			{
				if (!isset($options[$key]))		// If this option has not been set
				{
					$options[$key] = $a_default;
					$added = true;
				}
			}
		if ($added)
			update_option('widget_jsearch_options',$jsearch_options_defaults);
		return $options;
	}
	
	// This section writes a big, annoying reminder at the top of the page to set your jsearch target page
	$options = jsearch_get_options();
	$jsearch_page_id = $options['jsearch_target'];
	if (!isset($jsearch_page_id) || $jsearch_page_id == -1) // The page is set and isn't the default (no value)
	{
		function jsearch_warning() {
			echo "
			<div class='updated fade'><p><b>jsearch has not been configured:</b> Please go to the <a href=plugins.php?page=jsearch-options />Jsearch CONFIG</a> page to complete setup.</p><p>Note that if you DID set it and still see this warning, just ignore it. Your change worked as long as you see your page listed in the dropbox on the config page. I haven't figured out what causes this, but I'll save that for the next version.</p></div>
			";
		}
		add_action('admin_notices', 'jsearch_warning');
	}
	else
	{
		$temp = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE ID='$jsearch_page_id'");
		$GLOBALS['jsearch_target_page'] = $jsearch_target_page = get_permalink($temp);		// Swap the id for the permalink
	}


	//********************************
	//********************************
	//           Keyword widgets and boxes
	//********************************
	//********************************

	// This just writes a jsearch box where you want it. In case you need that.
	// This is a google like box for you to use.
	function jsearch_gbox($width=100,$height=17)
	{
		echo "<input type=text maxlength=30 id='jsearch_gsearch_box' class='jsearch_gsearch_box_off' style='width:".$width."px; height:".$height."px' />";		
	}

	// ********
	// Category listing and selector widget
	function widget_jsearch_catlist($args)
	{
		global $jsearch_target_page;
		global $post;
	
		extract($args);
		
		$options = get_option('widget_jsearch_terms');
		$jsearch_catlist_title = $options['jsearch_catlist_title'];	
		$jsearch_catlist_depth = $options['jsearch_catlist_depth'];	 
		$jsearch_catlist_cats = $options['jsearch_catlist_cats'];	 
	
		echo $before_widget.$before_title.$jsearch_catlist_title.$after_title;		
		//	Write the actual stuff now
		$var_string = "";
		if (isset($jsearch_catlist_depth)) $var_string .= "&depth=".$jsearch_catlist_depth;
		if (isset($jsearch_catlist_cats)) $var_string .= "&cats=".$jsearch_catlist_cats;
		$var_string = trim($var_string,"&");		// get rid of the leading & if there is one
		jsearch_print_cattags($var_string);
		jsearch_cat_go_button();
		echo $after_widget;
	}
		
	function widget_jsearch_catlist_control()
	{
		$options = $newoptions = jsearch_get_options();	
		if ($_POST['jsearch_catlist_submit']) 			// They changed options. Handle it
		{
			$newoptions['jsearch_catlist_title'] = jsearch_filter_denied($_POST['jsearch_catlist_title'],'"\\');		// Get title
			$newoptions['jsearch_catlist_depth'] = jsearch_reg_filter($_POST['jsearch_catlist_depth'],"0-9");		// Depth (force numeric)
			$newoptions['jsearch_catlist_cats'] = jsearch_filter_denied($_POST['jsearch_catlist_cats'],'"\\');		// Depth (force numeric)
		}
		if ($options != $newoptions)
			update_option('widget_jsearch_terms',$newoptions);
		
		$jsearch_catlist_title = htmlspecialchars($newoptions['jsearch_catlist_title'], ENT_QUOTES);
		$jsearch_catlist_depth = $newoptions['jsearch_catlist_depth'];
		$jsearch_catlist_cats = htmlspecialchars($newoptions['jsearch_catlist_cats'], ENT_QUOTES);

		// Title selector
		echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
		echo '<legend>Cat List Title</legend>';
			echo '<div style="width:100%; text-align:right"><input style="width:120px;" id=jsearch_catlist_title name=jsearch_catlist_title type="text" value="'.$jsearch_catlist_title.'" /></div>';
		echo "This changes the title of the search box shown on your sidebar.";		
		echo '</fieldset>';		

		// Depth
		echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
		echo '<legend>Depth</legend>';
		echo '<div style="width:100%; text-align:right"><select id=jsearch_catlist_depth name=jsearch_catlist_depth>';
		for ($i=10;$i>-1;--$i)
			echo ' <option value="'.$i.'" '.(($jsearch_catlist_depth==$i)?'selected="selected"':'').'>'.$i.'</option>';
		echo '</select></div>';
		echo "How deep do you want to print subcategories? 0 is parent categories only";		
		echo '</fieldset>';		

		// Depth
		echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
		echo '<legend>Categories</legend>';
			echo '<div style="width:100%; text-align:right"><input style="width:120px;" id=jsearch_catlist_cats name=jsearch_catlist_cats type="text" value="'.$jsearch_catlist_cats.'" /></div>';
		echo "If you want to print a specific category (or categories), enter the ids or names here (comma separated). Use correct capitalization and don't put spaces before or after the category names (just commas).";		
		echo '</fieldset>';		

		echo '<input type="hidden" name="jsearch_catlist_submit" value="1" />';
	}	

	wp_register_sidebar_widget( 'jsearch_catlist', 'Jsearch Cat List', 'widget_jsearch_catlist', array('description' => __('This prints a list of categories with checkboxes next to them so you can select multiple categories.')) );
	wp_register_widget_control( 'jsearch_catlist', 'Jsearch Cat List', 'widget_jsearch_catlist_control');
	// Category listing and selector widget
	// ********

	// This writes the replacement search box that would normally be added to sidebars
	function widget_jsearch_terms($args)
	{
		global $jsearch_target_page;
		global $post;
	
		extract($args);
		
		$options = get_option('widget_jsearch_terms');
		$jsearch_title = $options['jsearch_title'];	// A title for the second section
	
		echo $before_widget.$before_title.$jsearch_title.$after_title;		
		//	Write the actual stuff now
		echo "<div id=jsearch_sb>";
		echo "<input type=text id=jsearch_sb_terms maxlength=30  />";
		echo "<input id=jsearch_sb_button type=button value='Search'/><br/>";		// Note we call add_jsearch_term first in case they entered something and expected just clicking "search" to work, but they forgot to add it
		echo "<a id=jsearch_sb_advanced href=\"$jsearch_target_page\">Advanced Search</a>";
		echo "</div>";
		echo $after_widget;
	}
		
	// The options control in the widgets page for the jsearch replacement for standard search
	function widget_jsearch_terms_control()
	{
		$options = $newoptions = jsearch_get_options();	
		if ($_POST['jsearch_terms_submit']) 			// They changed options. Handle it
			$newoptions['jsearch_title'] = jsearch_filter_denied($_POST['jsearch_terms_title'],'"\\');		// Get title
		if ($options != $newoptions)
			update_option('widget_jsearch_terms',$newoptions);
		
		$jsearch_title = htmlspecialchars($newoptions['jsearch_title'], ENT_QUOTES);

		// Title selector
		echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
		echo '<legend>Search Box Title</legend>';
			echo '<div style="width:100%; text-align:right"><input style="width:120px;" id=jsearch_terms_title name=jsearch_terms_title type="text" value="'.$jsearch_title.'" /></div>';
		echo "This changes the title of the search box shown on your sidebar.";		
		echo '</fieldset>';		

		echo '<input type="hidden" name="jsearch_terms_submit" value="1" />';
	}	
		
	wp_register_sidebar_widget( 'jsearch_terms', 'jsearch Terms', 'widget_jsearch_terms', array('description' => __('This is a replacement for the standard Wordpress search. It includes a text entry box and search button, but it automatically goes to the jsearch page when used.')) );
	wp_register_widget_control( 'jsearch_terms', 'jsearch Terms', 'widget_jsearch_terms_control');


	//********************************
	//********************************
	//       PLUGIN Control panel
	//********************************
	//********************************


	function jsearch_admin_panel() 
	{
		if ( function_exists('add_submenu_page') )
			// 'manage-options' is a user security level that determines when this control will show
			// 'jsearch-options' is the name of the page that can be used to navigate to here. Useful for linking purposes
			// 'jsearch_admin_options' is the name of the function to call
			add_submenu_page('plugins.php', __('Jsearch Config'), __('Jsearch Config'), 'manage_options', 'jsearch-options' , 'jsearch_admin_options');
	}

	function jsearch_admin_options()
	{
	?>
		<div class='wrap'>
		<h2>Jsearch Options</h2>

		<?php
		$options = $newoptions = jsearch_get_options();
		if ($_POST['jsearch_options_submit']) 			// They changed options. Handle it
		{
			$newoptions['jsearch_target'] = $_POST['jsearch_target'];
			$newoptions['hide_search_titles'] =jsearch_reg_filter($_POST['jsearch_hide_search_titles'],"01");		// Show the control for searching titles?
			$newoptions['search_titles'] =jsearch_reg_filter($_POST['jsearch_search_titles'],"01");					// Set the default
			$newoptions['hide_search_content'] =jsearch_reg_filter($_POST['jsearch_hide_search_content'],"01");		// Show the control for searching content?
			$newoptions['search_content'] =jsearch_reg_filter($_POST['jsearch_search_content'],"01");				// Set the default
			$newoptions['hide_search_excerpts'] =jsearch_reg_filter($_POST['jsearch_hide_search_excerpts'],"01");	// Show the control for searching excerpts?
			$newoptions['search_excerpts'] =jsearch_reg_filter($_POST['jsearch_search_excerpts'],"01");				// Set the default
			$newoptions['hide_search_comments'] =jsearch_reg_filter($_POST['jsearch_hide_search_comments'],"01");	// Show the control for searching comments?
			$newoptions['search_comments'] =jsearch_reg_filter($_POST['jsearch_search_comments'],"01");				// Set the default
			$newoptions['hide_search_custom'] =jsearch_reg_filter($_POST['jsearch_hide_search_custom'],"01");		// Show the control for searching custom fields?
			$newoptions['search_custom'] =jsearch_reg_filter($_POST['jsearch_search_custom'],"01");					// Set the default
			$newoptions['hide_ppall'] =jsearch_reg_filter($_POST['jsearch_hide_ppall'],"01");			// Show the page/post/both selector?
			$newoptions['ppall'] =jsearch_reg_filter($_POST['jsearch_ppall'],"pagepostboth");			// Set the default
			$newoptions['hide_tefull'] =jsearch_reg_filter($_POST['jsearch_hide_tefull'],"01");			// Show the title/excerpt/full post selector?
			$newoptions['tefull'] =jsearch_reg_filter($_POST['jsearch_tefull'],"titleexcerptsfull");	// Set the default
			$newoptions['hide_ppp'] =jsearch_reg_filter($_POST['jsearch_hide_ppp'],"01");				// Show the Posts per page selector?
			$newoptions['ppp'] =jsearch_reg_filter($_POST['jsearch_ppp'],"0-9");						// Set the default
			$newoptions['hide_results_type'] =jsearch_reg_filter($_POST['jsearch_hide_results_type'],"01");				// Show the control?
			$newoptions['results_type'] =jsearch_reg_filter($_POST['jsearch_results_type'],"dual_listwpdefaultcustom123");		// Which type of results listing do you want?
			$newoptions['hide_order'] =jsearch_reg_filter($_POST['jsearch_hide_order'],"01");				// Show the control?
			$newoptions['order'] =jsearch_reg_filter($_POST['jsearch_order'],"ascdesc");			// What sort order should we use?
			$newoptions['hide_date'] =jsearch_reg_filter($_POST['jsearch_hide_date'],"01");				// Show the control?
			$newoptions['jsearch_hide_adder'] =jsearch_reg_filter($_POST['jsearch_hide_adder'],"01");				// Show the control?
			$newoptions['jsearch_hide_added'] =jsearch_reg_filter($_POST['jsearch_hide_added'],"01");				// Show the control?
			$newoptions['jsearch_hide_options'] =jsearch_reg_filter($_POST['jsearch_hide_options'],"01");				// Show the control?
		}
		if ($options != $newoptions)
			update_option('widget_jsearch_options',$newoptions);

		$jsearch_target = $newoptions['jsearch_target'];
		$hide_search_titles = $newoptions['hide_search_titles'];
		$search_titles = $newoptions['search_titles'];
		$hide_search_content = $newoptions['hide_search_content'];
		$search_content = $newoptions['search_content'];
		$hide_search_excerpts = $newoptions['hide_search_excerpts'];
		$search_excerpts = $newoptions['search_excerpts'];
		$hide_search_comments = $newoptions['hide_search_comments'];
		$search_comments = $newoptions['search_comments'];
		$hide_search_custom = $newoptions['hide_search_custom'];
		$search_custom = $newoptions['search_custom'];
		$hide_ppall = $newoptions['hide_ppall'];
		$ppall = $newoptions['ppall'];
		$hide_tefull = $newoptions['hide_tefull'];
		$tefull = $newoptions['tefull'];
		$hide_ppp = $newoptions['hide_ppp'];
		$ppp = $newoptions['ppp'];
		$hide_results_type = $newoptions['hide_results_type'];
		$results_type = $newoptions['results_type'];
		$hide_results_type = $newoptions['hide_date'];
		$hide_order = $newoptions['hide_order'];
		$jsearch_hide_adder = $newoptions['jsearch_hide_adder'];
		$jsearch_hide_added = $newoptions['jsearch_hide_added'];
		$jsearch_hide_options = $newoptions['jsearch_hide_options'];
		$order = $newoptions['order'];
		?>
		
		<form method="post">
		<?php wp_nonce_field('update-options'); ?>
		<table class="form-table" style="border:1px solid black; width:550px">
			<tr><td colspan=2 style="font-style:10pt">
			<h3>Basic Setup</h3>
			<b>1.</b> Copy the "jsearch_template.php" file from the JSEARCH plugin folder to your template folder<br/>
			<b>2.</b> Create a new page that uses the JSEARCH template you just copied.<br/>
			<b>3.</b> Return to this page and select your new jsearch page from this dropdown list.<br/>
			</td></tr>
			<tr valign="top">
			<th scope="row">Jsearch Target Page</th>
			<td>
			<select name="jsearch_target" > 
				<option value="-1">
				<?php echo attribute_escape(__('Select page')); ?></option> 
				<?php 
				$pages = get_pages(); 
				$current = (int) $jsearch_target;	// Get the existing value if there is one
				foreach ($pages as $pagg) 
				{
					$option = '<option value="'.$pagg->ID.'"';
					if ($current == $pagg->ID)
						$option .= "selected";
					$option .= '>';
					$option .= $pagg->post_title;
					$option .= '</option>';
					echo $option;
				}
				?>
			</select>
			</td>
			</tr>

			<tr valign="top">
			<td style="font-size:10pt" colspan=2>
			<p>
			Alternatively, you can put the jsearch code on any page you wish, but select it from this list so the code will know where to send someone who's doing a search.</p>
			</td>
			</tr>
			<tr>
			<td colspan=2>
				<hr>
				<h3>Search Page Options</h3>
				<p>On the search control itself (on the Jsearch page), there are several options for how the search works and looks.</p>
				<p>Here you can select the default options and whether or not the user can change the options or not.</p>
				<div style='width:350px; margin-left:auto; margin-right:auto;'>
				<?php

				// This section for writing the controls for what text is searched by keywords
				echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
				echo '<legend>Keyword Search Areas</legend>';
				echo "<p>Keywords will search each section that's turned on and will not search ones that are turned off.</p>";
				echo '<table>';
				echo '<tr>';
				// Title search
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_eng">User control:</label><br/>'. 
				' <select id="jsearch_hide_search_titles" name="jsearch_hide_search_titles">'.
				' <option value=0 '.(!$hide_search_titles?'selected="selected"':'').'>Visible</option>'.
				' <option value=1 '.($hide_search_titles?'selected="selected"':'').'>Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_search_titles">Default:</label><br/>'. 
				' <select id="jsearch_search_titles" name="jsearch_search_titles">'.
				' <option value="1" '.($search_titles?'selected="selected"':'').'>Search Titles</option>'.
				' <option value="0" '.(!$search_titles?'selected="selected"':'').'>Don\'t Search Titles</option>'.
				'</select></td>';		
				echo '</tr>';
				// Content search
				echo '<tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_eng">User control:</label><br/>'. 
				' <select id="jsearch_hide_search_content" name="jsearch_hide_search_content">'.
				' <option value=0 '.($hide_search_content?'selected="selected"':'').'>Visible</option>'.
				' <option value=1 '.($hide_search_content?'selected="selected"':'').'>Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_search_content">Default:</label><br/>'. 
				' <select id="jsearch_search_content" name="jsearch_search_content">'.
				' <option value="1" '.($search_content?'selected="selected"':'').'>Search Content</option>'.
				' <option value="0" '.(!$search_content?'selected="selected"':'').'>Don\'t Search Content</option>'.
				'</select></td>';		
				echo '</tr>';
				// Excerpt search
				echo '<tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_eng">User control:</label><br/>'. 
				' <select id="jsearch_hide_search_excerpts" name="jsearch_hide_search_excerpts">'.
				' <option value=0 '.(!$hide_search_excerpts?'selected="selected"':'').'>Visible</option>'.
				' <option value=1 '.($hide_search_excerpts?'selected="selected"':'').'>Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_search_excerpts">Default:</label><br/>'. 
				' <select id="jsearch_search_excerpts" name="jsearch_search_excerpts">'.
				' <option value="1" '.($search_excerpts?'selected="selected"':'').'>Search Excerpts</option>'.
				' <option value="0" '.(!$search_excerpts?'selected="selected"':'').'>Don\'t Search Excerpts</option>'.
				'</select></td>';		
				echo '</tr>';
				// Comments search

				echo '<tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_eng">User control:</label><br/>'. 
				' <select id="jsearch_hide_search_comments" name="jsearch_hide_search_comments">'.
				' <option value=0 '.(!$hide_search_comments?'selected="selected"':'').'>Visible</option>'.
				' <option value=1 '.($hide_search_comments?'selected="selected"':'').'>Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_search_comments">Default:</label><br/>'. 
				' <select id="jsearch_search_comments" name="jsearch_search_comments">'.
				' <option value="1" '.($search_comments?'selected="selected"':'').'>Search Comments</option>'.
				' <option value="0" '.(!$search_comments?'selected="selected"':'').'>Don\'t Search Comments</option>'.
				'</select></td>';		
				echo '</tr>';

				// Custom field search
				echo '<tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_eng">User control:</label><br/>'. 
				' <select id="jsearch_hide_search_custom" name="jsearch_hide_search_custom">'.
				' <option value=0 '.(!$hide_search_custom?'selected="selected"':'').'>Visible</option>'.
				' <option value=1 '.($hide_search_custom?'selected="selected"':'').'>Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_search_custom">Default:</label><br/>'. 
				' <select id="jsearch_search_custom" name="jsearch_search_custom">'.
				' <option value="1" '.($search_custom?'selected="selected"':'').'>Search Custom Fields</option>'.
				' <option value="0" '.(!$search_custom?'selected="selected"':'').'>Don\'t Search Custom Fields</option>'.
				'</select></td>';		
				echo '</tr>';
				echo '</table>';
				echo '</fieldset>';		
	
				// Jsearch Control Sections visibility (The adder area, the added area, and options)
				echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
				echo '<legend>Jsearch Control Visibility Options</legend>';
				echo "<p>On the Jsearch page, there's a large control with many options. If you want to hide some of them by default, use this control.</p><p>Users will still be able to turn the controls back on manually or via the url if desired.</p>";
				echo '<table><tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_adder">Adder Area:</label><br/>'. 
				' <select id="jsearch_hide_adder" name="jsearch_hide_adder">'.
				' <option value=0 '.(!$jsearch_hide_adder?'selected="selected"':'').'>Open</option>'.
				' <option value=1 '.($jsearch_hide_adder?'selected="selected"':'').'>Closed</option>'.
				'</select></td>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_added">Added Area:</label><br/>'. 
				' <select id="jsearch_hide_added" name="jsearch_hide_added">'.
				' <option value=0 '.(!$jsearch_hide_added?'selected="selected"':'').'>Open</option>'.
				' <option value=1 '.($jsearch_hide_added?'selected="selected"':'').'>Closed</option>'.
				'</select></td>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_options">Options Area:</label><br/>'. 
				' <select id="jsearch_hide_options" name="jsearch_hide_options">'.
				' <option value=0 '.(!$jsearch_hide_options?'selected="selected"':'').'>Open</option>'.
				' <option value=1 '.($jsearch_hide_options?'selected="selected"':'').'>Closed</option>'.
				'</select></td>';
				echo '</tr></table>';
				echo "<ol><li>Adder is the section that allows people to choose search items to add to the search.</li><li>Added is the the list of added search items terms. It's not normally a good idea to hide this unless you have a specific reasons.</li><li>Options are the list of detailed options that affect the way the search functions.</li></ol>";
				echo '</fieldset>';		
		
				// Pages vs posts vs both selector
				echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
				echo '<legend>Pages vs Posts Selector</legend>';
				echo "<p>Show resulting pages or just posts or both?</p>";
				echo '<table><tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_ppall">User control:</label><br/>'. 
				' <select id="jsearch_hide_ppall" name="jsearch_hide_ppall">'.
				' <option value=0 '.(!$hide_ppall?'selected="selected"':'').'>Visible</option>'.
				' <option value=1 '.($hide_ppall?'selected="selected"':'').'>Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_ppall">Default:</label><br/>'. 
				' <select id="jsearch_ppall" name="jsearch_ppall">'.
				' <option value="both" '.($ppall=='both'?'selected="selected"':'').'>Search Both</option>'.
				' <option value="pages" '.($ppall=='pages'?'selected="selected"':'').'>Search Pages Only</option>'.
				' <option value="posts" '.($ppall=='posts'?'selected="selected"':'').'>Search Posts Only</option>'.
				'</select></td>';
				echo '</tr></table>';
				echo '</fieldset>';		
		
				// Title vs excerpts vs full post selector
				echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
				echo '<legend>Title vs Excerpts Selector</legend>';
				echo "<p>Show just titles or title + excerpt.</p>";
				echo '<table><tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_tefull">User control:</label><br/>'. 
				' <select id="jsearch_hide_tefull" name="jsearch_hide_tefull">'.
				' <option value=0 '.(!$hide_tefull?'selected="selected"':'').'>Visible</option>'.
				' <option value=1 '.($hide_tefull?'selected="selected"':'').'>Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_tefull">Default:</label><br/>'. 
				' <select id="jsearch_tefull" name="jsearch_tefull">'.
				' <option value="excerpts" '.($tefull=='excerpts'?'selected="selected"':'').'>Show Titles and Excerpts</option>'.
				' <option value="title" '.($tefull=='title'?'selected="selected"':'').'>Show Titles Only</option>'.
				' <option value="full" '.($tefull=='full'?'selected="selected"':'').'>Show Full Posts</option>'.
				'</select></td>';		
				echo '</tr></table>';
				echo '</fieldset>';		
				
				// Posts per page. How many results show.
				echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
				echo '<legend>Posts Per Page Selector</legend>';
				echo "<p>How many results should show per page?</p>";
				echo '<table><tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_ppp">User control:</label><br/>'. 
				' <select id="jsearch_hide_ppp" name="jsearch_hide_ppp">'.
				' <option value=0 '.($hide_ppp?'':'selected="selected"').' >Visible</option>'.
				' <option value=1 '.($hide_ppp?'selected="selected"':'').' >Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_ppp">Default:</label><br/>'. 
				' <select id="jsearch_ppp" name="jsearch_ppp">';
				for ($i=1;$i<100;++$i)
					echo ' <option value="'.$i.'" '.(($ppp==$i)?'selected="selected"':'').'>'.$i.'</option>';
				echo '</select></td>';		
				echo '</tr></table>';
				echo '</fieldset>';		

				// Results listing type selector
				echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
				echo '<legend>Results display type</legend>';
				echo "<p>What should be the default method that results are listed in?</p>";
				echo '<table><tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_results_type">User control:</label><br/>'. 
				' <select id="jsearch_hide_results_type" name="jsearch_hide_results_type">'.
				' <option value=0 '.(!$hide_results_type?'selected="selected"':'').'>Visible</option>'.
				' <option value=1 '.($hide_results_type?'selected="selected"':'').'>Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_results_type">Default:</label><br/>'. 
				' <select id="jsearch_results_type" name="jsearch_results_type">'.
				' <option value="dual_list" '.($results_type=='dual_list'?'selected="selected"':'').'>Dual List (Jsearch Default)</option>'.
				' <option value="wp_default" '.($results_type=='wp_default'?'selected="selected"':'').'>Wordpress Default</option>'.
				' <option value="custom1" '.($results_type=='custom1'?'selected="selected"':'').'>Custom Listing 1</option>'.
				' <option value="custom2" '.($results_type=='custom2'?'selected="selected"':'').'>Custom Listing 2</option>'.
				' <option value="custom3" '.($results_type=='custom3'?'selected="selected"':'').'>Custom Listing 3</option>'.
				'</select></td>';
				echo '</tr></table>';
				echo '</fieldset>';		

				// Order: Ascending or Descending
				echo '<fieldset style="border:1px solid #bbbbbb; padding:3px; margin-bottom:7px;">';
				echo '<legend>Results Order (Asc/Desc)</legend>';
				echo "<p>Results are sorted by date, but do you want them shown in ascending order (from oldest post to newest) or descending (newest to oldest and the default)</p>";
				echo '<table><tr>';
				echo '<td style="width:100px" valign=top><label for="jsearch_hide_order">User control:</label><br/>'. 
				' <select id="jsearch_hide_order" name="jsearch_hide_order">'.
				' <option value=0 '.(!$hide_order?'selected="selected"':'').'>Visible</option>'.
				' <option value=1 '.($hide_order?'selected="selected"':'').'>Hidden</option>'.
				'</select></td>';		
				echo '<td valign=top><label for="jsearch_order">Default:</label><br/>'. 
				' <select id="jsearch_order" name="jsearch_order">'.
				' <option value="desc" '.($order=='desc'?'selected="selected"':'').'>Descending (default)</option>'.
				' <option value="asc" '.($order=='asc'?'selected="selected"':'').'>Ascending</option>'.
				'</select></td>';
				echo '</tr></table>';
				echo '</fieldset>';		
				?>
				</div>
			</td>
			</tr>


		</table>	
			
		<input type="hidden" name="action" value="update" />
		<input type="hidden" name="jsearch_options_submit" value=1 />
		<p class="submit">
		<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
		</p>
		</form>
		</div>

	<?php
	}
}

	//********************************
	//********************************
	//      Code for including various parts of jsearch
	// 		Because it seemed simpler to use in your template, each include is it's own function
	//********************************
	//********************************

function jsearch_control()
{
	global $jsearch_relative_url;

	require_once $jsearch_relative_url."jsearch_control.php";
}

	//********************************
	//********************************
	//       Add necessary Javascript functions to the header
	//********************************
	//********************************
function add_jsearch_js()
{
	global $jsearch_plugin_url;
	global $jsearch_target_page;
	global $jsearch_cats;

	echo "<script language='JavaScript' src='".$jsearch_plugin_url."jsearch_functions.js'>\n</script>\n";
	echo "<script language='JavaScript'>\n";
	echo "// Some JSEARCH related variables:";
	echo "\nvar jsearchPluginURL = '".$jsearch_plugin_url."';\n";	// Mostly for the improved category and tag printing functions that use AJAX
	echo "\nvar jsearchTargetPage = '".$jsearch_target_page."';\n";	// Be sure to set this variable or some of the JS freaks out
	jsearch_drop_vars("term");
	jsearch_drop_vars("cat");
	jsearch_drop_vars("tag");
	echo "var jsearchCats = new Array();\n";
	echo "var jsearchCatParents = new Array();\n";
	echo "var jsearchCatIndexes = new Array();\n";
	jsearch_drop_cats($jsearch_cats);
	echo "</script>\n";
}	

// And add the styles for this plugin to the head of the document (where css links go)	
add_filter('wp_head', 'add_jsearch_js');


	//********************************
	//********************************
	//       Add the jsearch styles to the header
	//********************************
	//********************************

// If you decide to modify the jsearch styles, you can put the file in your page template folder
// If you do, this function will add the styles to your theme for you. Otherwise, it will use the defaults
// Note that the reason you'd want to put the styles in your template folder is so you can make online edits
// REMEMBER to rename jsearch_default.css to jsearch.css and put it in your root template folder (Where your template php files are)
function add_jsearch_styles()
{
	global $jsearch_plugin_url;

	echo '<link rel="stylesheet" href="'.$jsearch_plugin_url.'/jsearch.css" type="text/css" media="screen" />'."\n";
}	

// And add the styles for this plugin 
add_filter('wp_head', 'add_jsearch_styles');



//*************************************
// DONE!
// Now get it going. Start 'er up!
add_action('widgets_init','widget_jsearch_init');
wp_enqueue_script('jquery');			// Load up jQuery (if it hasn't been already)

?>
